summaryrefslogtreecommitdiff
path: root/gpsd.c
diff options
context:
space:
mode:
authorGary E. Miller <gem@rellim.com>2016-04-24 15:26:48 -0700
committerGary E. Miller <gem@rellim.com>2016-04-24 15:30:56 -0700
commita8d12eea466d66d28104fb4b24274dc2168227f0 (patch)
tree0eb3dcd10678d046d7d7e1bf294c2a93ed61f3b2 /gpsd.c
parent9c3b5204a130be036eced73b7a7cde29f9a8157c (diff)
downloadgpsd-a8d12eea466d66d28104fb4b24274dc2168227f0.tar.gz
PPSTIME -> NTPTIME
NTPTIME is from the serial stream, it never had anything to do with PPS and it just confused everyone.
Diffstat (limited to 'gpsd.c')
-rw-r--r--gpsd.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/gpsd.c b/gpsd.c
index 28148e31..031ba1f6 100644
--- a/gpsd.c
+++ b/gpsd.c
@@ -1511,11 +1511,11 @@ static void all_reports(struct gps_device_t *device, gps_mask_t changed)
#ifdef NTP_ENABLE
/*
* Time is eligible for shipping to NTPD if the driver has
* asserted PPSTIME_IS at any point in the current cycle.
*/
if ((changed & CLEAR_IS)!=0)
device->ship_to_ntpd = false;
- if ((changed & PPSTIME_IS)!=0)
+ if ((changed & NTPTIME_IS)!=0)
device->ship_to_ntpd = true;
/*
* Only update the NTP time if we've seen the leap-seconds data.
@@ -1511,11 +1511,11 @@ static void all_reports(struct gps_device_t *device, gps_mask_t changed)
/*
* Time is eligible for shipping to NTPD if the driver has
- * asserted PPSTIME_IS at any point in the current cycle.
+ * asserted NTPTIME_IS at any point in the current cycle.
*/
if ((changed & CLEAR_IS)!=0)